package org.rcisoft.business.opmBlacklist.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang.StringUtils;
import org.rcisoft.business.memLeaveMessage.dao.MemLeaveMessageRepository;
import org.rcisoft.business.memLeaveMessage.entity.MemLeaveMessage;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.opmBlacklist.dao.OpmBlackListRepository;
import org.rcisoft.business.opmBlacklist.entity.OpmBlackList;
import org.rcisoft.business.opmBlacklist.service.OpmBlackListService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.math.BigInteger;
import java.util.Date;
import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2025年2月10日 上午9:46:37.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class OpmBlackListServiceImpl extends ServiceImpl<OpmBlackListRepository,OpmBlackList>  implements OpmBlackListService {

    @Autowired
    private MemLeaveMessageRepository memLeaveMessageRepository;

    /**
    * 保存 黑名单表
    * @param opmBlackList
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(OpmBlackList opmBlackList){
        //增加操作
        Integer userId = Integer.valueOf(CyUserUtil.getAuthenBusinessId());
        opmBlackList.setUserId(BigInteger.valueOf(userId));
        opmBlackList.setCreateDate(new Date());
        int line = baseMapper.insert(opmBlackList);
        //添加到对话表设置拉黑用户
        Integer targetId = opmBlackList.getTargetId().intValue();
        //biginteger转int
        MemLeaveMessage userTalk = memLeaveMessageRepository.queryUserTalk(userId, targetId);
        userTalk.setBlackUser(userId);
        memLeaveMessageRepository.updateUserTalk(userTalk);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            opmBlackList.getBusinessId()+"的黑名单表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 黑名单表
    * @param opmBlackList
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(OpmBlackList opmBlackList){
        int line = baseMapper.realDelete(opmBlackList);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            opmBlackList.getBusinessId()+"的黑名单表信息");
        return new CyPersistModel(line);
    }

    /**
    * 修改 黑名单表
    * @param opmBlackList
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(OpmBlackList opmBlackList){
        int line = baseMapper.updateById(opmBlackList);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ opmBlackList.getBusinessId()+"的黑名单表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 黑名单表
    * @param id
    * @return
    */
    @Override
    public OpmBlackList findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 黑名单表
    * @param opmBlackList
    * @return
    */
    @Override
    public IPage<OpmBlackList> findAllByPagination(CyPageInfo<OpmBlackList> paginationUtility,
        OpmBlackList opmBlackList){
        String userId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isNotEmpty(userId) && userId.equals("1")){
            //超级管理员
            return baseMapper.adminQueryOpmBlackListsPaged(paginationUtility,opmBlackList);
        } else {
            //普通用户
           opmBlackList.setUserId(BigInteger.valueOf(Integer.valueOf(userId)));
           return baseMapper.queryOpmBlackListsPaged(paginationUtility,opmBlackList);
        }
    }

    /**
    * 查询list 黑名单表
    * @param opmBlackList
    * @return
    */
    @Override
    public List<OpmBlackList> findAll(OpmBlackList opmBlackList){
        return baseMapper.queryOpmBlackLists(opmBlackList);

    }

    /**
    * 导出黑名单表
    * @return
    */
    @Override
    public List<OpmBlackList> export(OpmBlackList opmBlackList) {
        List<OpmBlackList> opmBlackListList = baseMapper.queryOpmBlackLists(opmBlackList);
        return opmBlackListList;
    }

}
